@@ -8,7 +8,9 @@ import requests
 from dtale import utils as _utils
 from dtale import views as _views
 
-dtale.app.initialize_process_props()
+from dtale_desktop.settings import settings
+
+dtale.app.initialize_process_props(host=settings.HOST, port=settings.DTALE_PORT)
 
 DTALE_HOST = dtale.app.ACTIVE_HOST
 
